@@ -11,9 +11,15 @@ import sys
 from google.cloud.bigquery import Client, LoadJobConfig, DatasetReference
 from google.cloud.bigquery import SchemaField as sf
 from google.oauth2 import service_account
+from CsPy_Uploading.classes import DownloadJob
+from CsPy_Uploading.classes import DownloadSettings
 from CsPy_Uploading.classes import UploadJob
 from CsPy_Uploading.classes import UploadSettings
 from CsPy_Uploading.classes import Account
+# from CsPy_Uploading.classes import DownloadScriptFailure
+from CsPy_Uploading.classes import InputError
+from CsPy_Uploading.classes import InputTypeError
+from CsPy_Uploading.classes import ColumnMissingError
 from CsPy_Uploading.functions import read_query_from_file
 from CsPy_Uploading.functions import left
 from CsPy_Uploading.functions import right
@@ -26,4 +32,5 @@ from CsPy_Uploading.functions import save_excel_sheets_to_csv
 from CsPy_Uploading.functions import delete_folder_contents
 from CsPy_Uploading.functions import date_convert
 from CsPy_Uploading.functions import sql_to_workbook
+from CsPy_Uploading.functions import date_selection
 
